0.9.45
------

* create a placeholder and an exception for form "parse errors"

0.9.44
------

* fix parameter passing in ``describe_multiseek_data``

0.9.43
------

* fix for DateQueryObject when there was range given
* fix for ``impacts_query`` parameters passing & test


0.9.32
------

* Foundation 6 as the only supported theme
